@@ -43,6 +43,7 @@ class HTTPFileSystem(AsyncFileSystem):
     HTML href tags will be used.
     """
 
+    protocol = ("http", "https")
     sep = "/"
 
     def __init__(
@@ -326,7 +327,7 @@ class HTTPFileSystem(AsyncFileSystem):
         async with meth(self.encode_url(rpath), data=gen_chunks(), **kw) as resp:
             self._raise_not_found_for_status(resp, rpath)
 
-    async def _exists(self, path, **kwargs):
+    async def _exists(self, path, strict=False, **kwargs):
         kw = self.kwargs.copy()
         kw.update(kwargs)
         try:
@@ -334,8 +335,14 @@ class HTTPFileSystem(AsyncFileSystem):
             session = await self.set_session()
             r = await session.get(self.encode_url(path), **kw)
             async with r:
+                if strict:
+                    self._raise_not_found_for_status(r, path)
                 return r.status < 400
+        except FileNotFoundError:
+            return False
         except aiohttp.ClientError:
+            if strict:
+                raise
             return False
 
     async def _isfile(self, path, **kwargs):
@@ -873,7 +880,7 @@ async def _file_info(url, session, size_policy="head", **kwargs):
 
         info["url"] = str(r.url)
 
-        for checksum_field in ["ETag", "Content-MD5", "Digest"]:
+        for checksum_field in ["ETag", "Content-MD5", "Digest", "Last-Modified"]:
             if r.headers.get(checksum_field):
                 info[checksum_field] = r.headers[checksum_field]
 
